# User guide

```{toctree}
Campaigns <campaigns>
Constraints <constraints>
Objective <objective>
Parameters <parameters>
Recommenders <recommenders>
Search Spaces <searchspace>
Simulation <simulation>
Surrogates <surrogates>
Targets <targets>
Transfer Learning <transfer_learning>
```